zope.security.protectclass — zope.security 4.0dev documentation

# `zope.security.protectclass`

Make assertions about permissions needed to access instance attributes

`zope.security.protectclass.` `protectName`(class_, name, permission)

  Set a permission on a particular name.

`zope.security.protectclass.` `protectSetAttribute`(class_, name, permission)

  Set a permission on a particular name.

`zope.security.protectclass.` `protectLikeUnto`(class_, like_unto)

  Use the protections from like_unto for the given class.